@@ -1,4 +1,4 @@
 .First.lib <- function(lib, pkg) {
-require(sound)
+try(require("sound")) 
 cat("Welcome to seewave!\nThe package is regularly updated, check for new version\nPlease see citation('seewave') if you use 'seewave' in publications\n")
 }
